@@ -28,7 +28,8 @@ our @EXPORT_OK = qw( _is_lnk
 		     _glob_to_regex
                      _file_part
                      _umask_save_and_set
-                     _tcroak );
+                     _tcroak
+                     _untaint );
 
 our $debug;
 
@@ -45,12 +46,15 @@ sub _debug {
 	$caller =~ s/[\w:]*:://;
 	$caller .= ': ';
     }
+
+    my $line = join(' ', map { defined $_ ? $_ : '<undef>' } @_);
+
     if ($debug & 256) {
 	my $ts = sprintf("%010.5f", time);
-        print STDERR "#$$ $ts $caller", @_,"\n"
+        print STDERR "#$$ $ts $caller $line\n";
     }
     else {
-        print STDERR "# $caller", @_,"\n"
+        print STDERR "# $caller $line\n";
     }
 }
 
@@ -308,6 +312,15 @@ sub _file_part {
     $1;
 }
 
+sub _untaint {
+    if (${^TAINT}) {
+        for (@_) {
+            defined or next;
+            ($_) = /(.*)/s
+        }
+    }
+}
+
 sub _umask_save_and_set {
     my $umask = shift;
     if (defined $umask) {
